==> huaweicloudsdkfunctiongraph-3.1.97-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/update_version_alias_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateVersionAliasRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'version': 'str',
        'description': 'str',
        'additional_version_weights': 'dict(str, int)',
        'additional_version_strategy': 'dict(str, VersionStrategy)'
    }

    attribute_map = {
        'version': 'version',
        'description': 'description',
        'additional_version_weights': 'additional_version_weights',
        'additional_version_strategy': 'additional_version_strategy'
    }

    def __init__(self, version=None, description=None, additional_version_weights=None, additional_version_strategy=None):
        """UpdateVersionAliasRequestBody

        The model defined in huaweicloud sdk

        :param version: 别名对应的版本名称。
        :type version: str
        :param description: 别名描述信息。
        :type description: str
        :param additional_version_weights: 灰度版本信息
        :type additional_version_weights: dict(str, int)
        :param additional_version_strategy: 指定规则灰度策略信息
        :type additional_version_strategy: dict(str, VersionStrategy)
        """
        
        

        self._version = None
        self._description = None
        self._additional_version_weights = None
        self._additional_version_strategy = None
        self.discriminator = None

        self.version = version
        if description is not None:
            self.description = description
        if additional_version_weights is not None:
            self.additional_version_weights = additional_version_weights
        if additional_version_strategy is not None:
            self.additional_version_strategy = additional_version_strategy

    @property
    def version(self):
        """Gets the version of this UpdateVersionAliasRequestBody.

        别名对应的版本名称。

        :return: The version of this UpdateVersionAliasRequestBody.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this UpdateVersionAliasRequestBody.

        别名对应的版本名称。

        :param version: The version of this UpdateVersionAliasRequestBody.
        :type version: str
        """
        self._version = version

    @property
    def description(self):
        """Gets the description of this UpdateVersionAliasRequestBody.

        别名描述信息。

        :return: The description of this UpdateVersionAliasRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateVersionAliasRequestBody.

        别名描述信息。

        :param description: The description of this UpdateVersionAliasRequestBody.
        :type description: str
        """
        self._description = description

    @property
    def additional_version_weights(self):
        """Gets the additional_version_weights of this UpdateVersionAliasRequestBody.

        灰度版本信息

        :return: The additional_version_weights of this UpdateVersionAliasRequestBody.
        :rtype: dict(str, int)
        """
        return self._additional_version_weights

    @additional_version_weights.setter
    def additional_version_weights(self, additional_version_weights):
        """Sets the additional_version_weights of this UpdateVersionAliasRequestBody.

        灰度版本信息

        :param additional_version_weights: The additional_version_weights of this UpdateVersionAliasRequestBody.
        :type additional_version_weights: dict(str, int)
        """
        self._additional_version_weights = additional_version_weights

    @property
    def additional_version_strategy(self):
        """Gets the additional_version_strategy of this UpdateVersionAliasRequestBody.

        指定规则灰度策略信息

        :return: The additional_version_strategy of this UpdateVersionAliasRequestBody.
        :rtype: dict(str, VersionStrategy)
        """
        return self._additional_version_strategy

    @additional_version_strategy.setter
    def additional_version_strategy(self, additional_version_strategy):
        """Sets the additional_version_strategy of this UpdateVersionAliasRequestBody.

        指定规则灰度策略信息

        :param additional_version_strategy: The additional_version_strategy of this UpdateVersionAliasRequestBody.
        :type additional_version_strategy: dict(str, VersionStrategy)
        """
        self._additional_version_strategy = additional_version_strategy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVersionAliasRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfunctiongraph-3.1.145-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/update_version_alias_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateVersionAliasRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'version': 'str',
        'description': 'str',
        'additional_version_weights': 'dict(str, int)',
        'additional_version_strategy': 'dict(str, VersionStrategy)'
    }

    attribute_map = {
        'version': 'version',
        'description': 'description',
        'additional_version_weights': 'additional_version_weights',
        'additional_version_strategy': 'additional_version_strategy'
    }

    def __init__(self, version=None, description=None, additional_version_weights=None, additional_version_strategy=None):
        r"""UpdateVersionAliasRequestBody

        The model defined in huaweicloud sdk

        :param version: 别名对应的版本名称。
        :type version: str
        :param description: 别名描述信息。
        :type description: str
        :param additional_version_weights: 灰度版本信息
        :type additional_version_weights: dict(str, int)
        :param additional_version_strategy: 指定规则灰度策略信息
        :type additional_version_strategy: dict(str, VersionStrategy)
        """
        
        

        self._version = None
        self._description = None
        self._additional_version_weights = None
        self._additional_version_strategy = None
        self.discriminator = None

        self.version = version
        if description is not None:
            self.description = description
        if additional_version_weights is not None:
            self.additional_version_weights = additional_version_weights
        if additional_version_strategy is not None:
            self.additional_version_strategy = additional_version_strategy

    @property
    def version(self):
        r"""Gets the version of this UpdateVersionAliasRequestBody.

        别名对应的版本名称。

        :return: The version of this UpdateVersionAliasRequestBody.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        r"""Sets the version of this UpdateVersionAliasRequestBody.

        别名对应的版本名称。

        :param version: The version of this UpdateVersionAliasRequestBody.
        :type version: str
        """
        self._version = version

    @property
    def description(self):
        r"""Gets the description of this UpdateVersionAliasRequestBody.

        别名描述信息。

        :return: The description of this UpdateVersionAliasRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        r"""Sets the description of this UpdateVersionAliasRequestBody.

        别名描述信息。

        :param description: The description of this UpdateVersionAliasRequestBody.
        :type description: str
        """
        self._description = description

    @property
    def additional_version_weights(self):
        r"""Gets the additional_version_weights of this UpdateVersionAliasRequestBody.

        灰度版本信息

        :return: The additional_version_weights of this UpdateVersionAliasRequestBody.
        :rtype: dict(str, int)
        """
        return self._additional_version_weights

    @additional_version_weights.setter
    def additional_version_weights(self, additional_version_weights):
        r"""Sets the additional_version_weights of this UpdateVersionAliasRequestBody.

        灰度版本信息

        :param additional_version_weights: The additional_version_weights of this UpdateVersionAliasRequestBody.
        :type additional_version_weights: dict(str, int)
        """
        self._additional_version_weights = additional_version_weights

    @property
    def additional_version_strategy(self):
        r"""Gets the additional_version_strategy of this UpdateVersionAliasRequestBody.

        指定规则灰度策略信息

        :return: The additional_version_strategy of this UpdateVersionAliasRequestBody.
        :rtype: dict(str, VersionStrategy)
        """
        return self._additional_version_strategy

    @additional_version_strategy.setter
    def additional_version_strategy(self, additional_version_strategy):
        r"""Sets the additional_version_strategy of this UpdateVersionAliasRequestBody.

        指定规则灰度策略信息

        :param additional_version_strategy: The additional_version_strategy of this UpdateVersionAliasRequestBody.
        :type additional_version_strategy: dict(str, VersionStrategy)
        """
        self._additional_version_strategy = additional_version_strategy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVersionAliasRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
